Add operations
The add module contains functionality relating to the add command, independent of the CLI.
Structs
The options available to the add command.
Functions
Adds user provided content to a diary entry.
The add module contains functionality relating to the add command, independent of the CLI.
The options available to the add command.
Adds user provided content to a diary entry.