pub fn add(
    opts: &AddOptions<'_>,
    config: &Config,
    date: &Date<Local>,
    string_getter: StringGetter
) -> Result<(), DiaryError>
Adds user provided content to a diary entry.

Arguments

  • opts - The options available to the add function.
  • config - The diary config file.
  • date - The date of the entry to add to.
  • string_getter - The function that obtains the string to add to the file.

Returns

The unit if adding the content was successful, a DiaryError otherwise.