pub struct NewOptions {
pub open: bool,
}Expand description
The options available to the new command.
Fields
open: boolWhether or not to open the new entry for an initial entry.
pub struct NewOptions {
pub open: bool,
}The options available to the new command.
open: boolWhether or not to open the new entry for an initial entry.