Open operations
The open module contains functionality relating to the open command, independent of the CLI.
Structs
The options available to the open command.
Functions
Opens a specific diary entry for editing.
The open module contains functionality relating to the open command, independent of the CLI.
The options available to the open command.
Opens a specific diary entry for editing.